@@ -38,7 +38,7 @@ class CreditCard(Resource):
         print(result.credit_card.token)
         print(result.credit_card.masked_number)
 
-    For more information on CreditCards, see https://developers.braintreepayments.com/ios+python/reference/request/credit-card/create
+    For more information on CreditCards, see https://developers.braintreepayments.com/reference/request/credit-card/create/python
 
     """
     class CardType(object):
