@@ -24,6 +24,7 @@ class ErrorCodes(object):
         FirstNameIsInvalid = "91819"
         FirstNameIsTooLong = "81805"
         InconsistentCountry = "91815"
+        IsInvalid = "91828"
         LastNameIsInvalid = "91820"
         LastNameIsTooLong = "81806"
         LocalityIsInvalid = "91824"
@@ -134,6 +135,7 @@ class ErrorCodes(object):
             UpdateExistingTokenNotAllowed = "91729"
             VerificationAmountCannotBeNegative = "91739"
             VerificationAmountFormatIsInvalid = "91740"
+            VerificationAmountIsTooLarge = "91752"
             VerificationAmountNotSupportedByProcessor = "91741"
             VerificationMerchantAccountIdIsInvalid = "91728"
             VerificationMerchantAccountIsForbidden = "91743"
@@ -179,10 +181,12 @@ class ErrorCodes(object):
         CountryCodeNumericIsNotAccepted = "93608"
         CountryNameIsInvalid = "93611"
         CountryNameIsNotAccepted = "93610"
+        CurrenciesAreInvalid = "93614"
         EmailFormatIsInvalid = "93602"
         EmailIsRequired = "83601"
         InconsistentCountry = "93612"
         PaymentMethodsAreInvalid = "93613"
+        PaymentMethodsAreNotAllowed = "93615"
 
     class MerchantAccount(object):
         IdFormatIsInvalid = "82603"
@@ -295,6 +299,7 @@ class ErrorCodes(object):
         class Options(object):
             AmountCannotBeNegative = "94201"
             AmountFormatIsInvalid = "94202"
+            AmountIsTooLarge = "94207"
             AmountNotSupportedByProcessor = "94203"
             MerchantAccountIdIsInvalid = "94204"
             MerchantAccountIsSuspended = "94205"
@@ -441,6 +446,7 @@ class ErrorCodes(object):
         CannotSimulateTransactionSettlement = "91575"
         CannotSubmitForPartialSettlement = "915103"
         CannotSubmitForSettlement = "91507"
+        CannotUpdateTransactionDetailsNotSubmittedForSettlement = "915129"
         ChannelIsTooLong = "91550"
         ChannelIsTooLong = "91550"
         CreditCardIsRequired = "91508"
@@ -481,6 +487,7 @@ class ErrorCodes(object):
         ProcessorDoesNotSupportPartialSettlement = "915102"
         ProcessorDoesNotSupportUpdatingOrderId = "915107"
         ProcessorDoesNotSupportUpdatingDescriptor = "915108"
+        ProcessorDoesNotSupportUpdatingTransactionDetails = "915130"
         ProcessorDoesNotSupportVoiceAuthorizations = "91545"
         PurchaseOrderNumberIsInvalid = "91548"
         PurchaseOrderNumberIsTooLong = "91537"
@@ -504,6 +511,11 @@ class ErrorCodes(object):
         ThreeDSecureAuthenticationFailed = "81571"
         ThreeDSecureTokenIsInvalid = "91568"
         ThreeDSecureTransactionDataDoesntMatchVerify = "91570"
+        ThreeDSecureEciFlagIsRequired = "915113"
+        ThreeDSecureCavvIsRequired = "915116"
+        ThreeDSecureXidIsRequired = "915115"
+        ThreeDSecureEciFlagIsInvalid = "915114"
+        ThreeDSecureMerchantAccountDoesNotSupportCardType = "915131"
         TypeIsInvalid = "91523"
         TypeIsRequired = "91524"
         UnsupportedVoiceAuthorization = "91539"
@@ -534,4 +546,3 @@ class ErrorCodes(object):
                 DepartureDateIsInvalid = "93411"
                 LodgingCheckInDateIsInvalid = "93412"
                 LodgingCheckOutDateIsInvalid = "93413"
-
